"""
Compute a CRC-32 checksum of data.
"""
from typing import Optional

from .fastcrc import crc_32_aixm as _crc_32_aixm
from .fastcrc import crc_32_autosar as _crc_32_autosar
from .fastcrc import crc_32_base91_d as _crc_32_base91_d
from .fastcrc import crc_32_bzip2 as _crc_32_bzip2
from .fastcrc import crc_32_cd_rom_edc as _crc_32_cd_rom_edc
from .fastcrc import crc_32_cksum as _crc_32_cksum
from .fastcrc import crc_32_iscsi as _crc_32_iscsi
from .fastcrc import crc_32_iso_hdlc as _crc_32_iso_hdlc
from .fastcrc import crc_32_jamcrc as _crc_32_jamcrc
from .fastcrc import crc_32_mpeg_2 as _crc_32_mpeg_2
from .fastcrc import crc_32_xfer as _crc_32_xfer
from .fastcrc import (
    crc_32_k_reversed_reciprocal_refin as _crc_32_k_reversed_reciprocal_refin,
)

__always_supported = (
    "aixm",
    "autosar",
    "base91_d",
    "bzip2",
    "cd_rom_edc",
    "cksum",
    "iscsi",
    "iso_hdlc",
    "jamcrc",
    "mpeg_2",
    "xfer",
)

algorithms_guaranteed = set(__always_supported)
algorithms_available = set(__always_supported)


def aixm(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `aixm` algorithm.

    Algorithm parameters:
        - ploy: 0x814141ab
        - init: 0x00000000
        - xorout: 0x00000000
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_aixm(data, initial)


def autosar(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `autosar` algorithm.

    Algorithm parameters:
        - ploy: 0xf4acfb13
        - init: 0xffffffff
        - xorout: 0xffffffff
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_autosar(data, initial)


def base91_d(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `base91 d` algorithm.

    Algorithm parameters:
        - ploy: 0xa833982b
        - init: 0xffffffff
        - xorout: 0xffffffff
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_base91_d(data, initial)


def bzip2(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `bzip2` algorithm.

    Algorithm parameters:
        - ploy: 0x04c11db7
        - init: 0xffffffff
        - xorout: 0xffffffff
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_bzip2(data, initial)


def cd_rom_edc(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `cd rom edc` algorithm.

    Algorithm parameters:
        - ploy: 0x8001801b
        - init: 0x00000000
        - xorout: 0x00000000
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_cd_rom_edc(data, initial)


def cksum(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `cksum` algorithm.

    Algorithm parameters:
        - ploy: 0x04c11db7
        - init: 0x00000000
        - xorout: 0xffffffff
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_cksum(data, initial)


def iscsi(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `iscsi` algorithm.

    Algorithm parameters:
        - ploy: 0x1edc6f41
        - init: 0xffffffff
        - xorout: 0xffffffff
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_iscsi(data, initial)


def iso_hdlc(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `iso hdlc` algorithm.

    Algorithm parameters:
        - ploy: 0x04c11db7
        - init: 0xffffffff
        - xorout: 0xffffffff
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_iso_hdlc(data, initial)


def jamcrc(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `jamcrc` algorithm.

    Algorithm parameters:
        - ploy: 0x04c11db7
        - init: 0xffffffff
        - xorout: 0x00000000
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_jamcrc(data, initial)


def mpeg_2(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `mpeg 2` algorithm.

    Algorithm parameters:
        - ploy: 0x04c11db7
        - init: 0xffffffff
        - xorout: 0x00000000
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_mpeg_2(data, initial)


def xfer(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `xfer` algorithm.

    Algorithm parameters:
        - ploy: 0x000000af
        - init: 0x00000000
        - xorout: 0x00000000
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_xfer(data, initial)


def k_reversed_reciprocal_refin(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the `k reversed reciprocal refin` algorithm.

    **This method may be removed in the future.**

    Algorithm parameters:
        - ploy: 0xba0dc66b
        - init: 0x00000000
        - xorout: 0x00000000
        - refin: True
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_32_k_reversed_reciprocal_refin(data, initial)



from . import crc8, crc16, crc32, crc64
from .__info__ import (
    __author__,
    __author_email__,
    __description__,
    __issues__,
    __license__,
    __title__,
    __url__,
    __version__,
)



"""
Compute a CRC-64 checksum of data.
"""
from typing import Optional

from .fastcrc import crc_64_ecma_182 as _crc_64_ecma_182
from .fastcrc import crc_64_go_iso as _crc_64_go_iso
from .fastcrc import crc_64_we as _crc_64_we
from .fastcrc import crc_64_xz as _crc_64_xz
from .fastcrc import crc_64_tms570_iso as _crc_64_tms570_iso

__always_supported = ("ecma_182", "go_iso", "we", "xz", "tms570_iso")

algorithms_guaranteed = set(__always_supported)
algorithms_available = set(__always_supported)


def ecma_182(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-64 checksum of data with the `ecma 182` algorithm.

    Algorithm parameters:
        - ploy: 0x42f0e1eba9ea3693
        - init: 0x0000000000000000
        - xorout: 0x0000000000000000
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_64_ecma_182(data, initial)


def go_iso(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-64 checksum of data with the `go iso` algorithm.

    Algorithm parameters:
        - ploy: 0x000000000000001b
        - init: 0xffffffffffffffff
        - xorout: 0xffffffffffffffff
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_64_go_iso(data, initial)


def we(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-64 checksum of data with the `we` algorithm.

    Algorithm parameters:
        - ploy: 0x42f0e1eba9ea3693
        - init: 0xffffffffffffffff
        - xorout: 0xffffffffffffffff
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_64_we(data, initial)


def xz(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-64 checksum of data with the `xz` algorithm.

    Algorithm parameters:
        - ploy: 0x42f0e1eba9ea3693
        - init: 0xffffffffffffffff
        - xorout: 0xffffffffffffffff
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_64_xz(data, initial)


def tms570_iso(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-64 checksum of data with the `tms570_iso` algorithm.

    Algorithm parameters:
        - poly: 0x000000000000001b
        - init: 0x0000000000000000
        - xorout: 0x0000000000000000
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_64_tms570_iso(data, initial)



"""
Compute a CRC-16 checksum of data.
"""
from typing import Optional

from .fastcrc import crc_8_autosar as _crc_8_autosar
from .fastcrc import crc_8_bluetooth as _crc_8_bluetooth
from .fastcrc import crc_8_cdma2000 as _crc_8_cdma2000
from .fastcrc import crc_8_darc as _crc_8_darc
from .fastcrc import crc_8_dvb_s2 as _crc_8_dvb_s2
from .fastcrc import crc_8_gsm_a as _crc_8_gsm_a
from .fastcrc import crc_8_gsm_b as _crc_8_gsm_b
from .fastcrc import crc_8_i_432_1 as _crc_8_i_432_1
from .fastcrc import crc_8_i_code as _crc_8_i_code
from .fastcrc import crc_8_lte as _crc_8_lte
from .fastcrc import crc_8_maxim_dow as _crc_8_maxim_dow
from .fastcrc import crc_8_mifare_mad as _crc_8_mifare_mad
from .fastcrc import crc_8_nrsc_5 as _crc_8_nrsc_5
from .fastcrc import crc_8_opensafety as _crc_8_opensafety
from .fastcrc import crc_8_rohc as _crc_8_rohc
from .fastcrc import crc_8_sae_j1850 as _crc_8_sae_j1850
from .fastcrc import crc_8_smbus as _crc_8_smbus
from .fastcrc import crc_8_tech_3250 as _crc_8_tech_3250
from .fastcrc import crc_8_wcdma as _crc_8_wcdma

__always_supported = (
    "autosar",
    "bluetooth",
    "cdma2000",
    "darc",
    "dvb_s2",
    "gsm_a",
    "gsm_b",
    "i_432_1",
    "i_code",
    "lte",
    "maxim_dow",
    "mifare_mad",
    "nrsc_5",
    "opensafety",
    "rohc",
    "sae_j1850",
    "smbus",
    "tech_3250",
    "wcdma",
)

algorithms_guaranteed = set(__always_supported)
algorithms_available = set(__always_supported)

def autosar(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `autosar` algorithm.

    Algorithm parameters:
        - poly: 0x2f
        - init: 0xff
        - xorout: 0xff
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_autosar(data, initial)


def bluetooth(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `bluetooth` algorithm.

    Algorithm parameters:
        - poly: 0xa7
        - init: 0x00
        - xorout: 0x00
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_bluetooth(data, initial)


def cdma2000(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `cdma2000` algorithm.

    Algorithm parameters:
        - poly: 0x9b
        - init: 0xff
        - xorout: 0x00
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_cdma2000(data, initial)


def darc(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `darc` algorithm.

    Algorithm parameters:
        - poly: 0x39
        - init: 0x00
        - xorout: 0x00
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_darc(data, initial)


def dvb_s2(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `dvb_s2` algorithm.

    Algorithm parameters:
        - poly: 0xd5
        - init: 0x00
        - xorout: 0x00
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_dvb_s2(data, initial)


def gsm_a(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `gsm_a` algorithm.

    Algorithm parameters:
        - poly: 0x1d
        - init: 0x00
        - xorout: 0x00
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_gsm_a(data, initial)


def gsm_b(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `gsm_b` algorithm.

    Algorithm parameters:
        - poly: 0x49
        - init: 0x00
        - xorout: 0xff
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_gsm_b(data, initial)


def i_432_1(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `i_432_1` algorithm.

    Algorithm parameters:
        - poly: 0x07
        - init: 0x00
        - xorout: 0x55
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_i_432_1(data, initial)


def i_code(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `i_code` algorithm.

    Algorithm parameters:
        - poly: 0x1d
        - init: 0xfd
        - xorout: 0x00
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_i_code(data, initial)


def lte(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `lte` algorithm.

    Algorithm parameters:
        - poly: 0x9b
        - init: 0x00
        - xorout: 0x00
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_lte(data, initial)


def maxim_dow(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `maxim_dow` algorithm.

    Algorithm parameters:
        - poly: 0x31
        - init: 0x00
        - xorout: 0x00
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_maxim_dow(data, initial)


def mifare_mad(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `mifare_mad` algorithm.

    Algorithm parameters:
        - poly: 0x1d
        - init: 0xc7
        - xorout: 0x00
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_mifare_mad(data, initial)


def nrsc_5(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `nrsc_5` algorithm.

    Algorithm parameters:
        - poly: 0x31
        - init: 0xff
        - xorout: 0x00
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_nrsc_5(data, initial)


def opensafety(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `opensafety` algorithm.

    Algorithm parameters:
        - poly: 0x2f
        - init: 0x00
        - xorout: 0x00
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_opensafety(data, initial)


def rohc(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `rohc` algorithm.

    Algorithm parameters:
        - poly: 0x07
        - init: 0xff
        - xorout: 0x00
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_rohc(data, initial)


def sae_j1850(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `sae_j1850` algorithm.

    Algorithm parameters:
        - poly: 0x1d
        - init: 0xff
        - xorout: 0xff
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_sae_j1850(data, initial)


def smbus(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `smbus` algorithm.

    Algorithm parameters:
        - poly: 0x07
        - init: 0x00
        - xorout: 0x00
        - refin: False
        - refout: False

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_smbus(data, initial)


def tech_3250(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `tech_3250` algorithm.

    Algorithm parameters:
        - poly: 0x1d
        - init: 0xff
        - xorout: 0x00
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_tech_3250(data, initial)


def wcdma(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-8 checksum of data with the `wcdma` algorithm.

    Algorithm parameters:
        - poly: 0x9b
        - init: 0x00
        - xorout: 0x00
        - refin: True
        - refout: True

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    return _crc_8_wcdma(data, initial)


import pytest
from fastcrc import crc16, crc32, crc64

test_data = b"123456789"


@pytest.mark.benchmark(group="crc_16_arc")
def test_crc_16_arc(benchmark):
    benchmark(crc16.arc, test_data)


@pytest.mark.benchmark(group="crc_16_cdma2000")
def test_crc_16_cdma2000(benchmark):
    benchmark(crc16.cdma2000, test_data)


@pytest.mark.benchmark(group="crc_16_cms")
def test_crc_16_cms(benchmark):
    benchmark(crc16.cms, test_data)


@pytest.mark.benchmark(group="crc_16_dds_110")
def test_crc_16_dds_110(benchmark):
    benchmark(crc16.dds_110, test_data)


@pytest.mark.benchmark(group="crc_16_dect_r")
def test_crc_16_dect_r(benchmark):
    benchmark(crc16.dect_r, test_data)


@pytest.mark.benchmark(group="crc_16_dect_x")
def test_crc_16_dect_x(benchmark):
    benchmark(crc16.dect_x, test_data)


@pytest.mark.benchmark(group="crc_16_dnp")
def test_crc_16_dnp(benchmark):
    benchmark(crc16.dnp, test_data)


@pytest.mark.benchmark(group="crc_16_en_13757")
def test_crc_16_en_13757(benchmark):
    benchmark(crc16.en_13757, test_data)


@pytest.mark.benchmark(group="crc_16_genibus")
def test_crc_16_genibus(benchmark):
    benchmark(crc16.genibus, test_data)


@pytest.mark.benchmark(group="crc_16_gsm")
def test_crc_16_gsm(benchmark):
    benchmark(crc16.gsm, test_data)


@pytest.mark.benchmark(group="crc_16_ibm_3740")
def test_crc_16_ibm_3740(benchmark):
    benchmark(crc16.ibm_3740, test_data)


@pytest.mark.benchmark(group="crc_16_ibm_sdlc")
def test_crc_16_ibm_sdlc(benchmark):
    benchmark(crc16.ibm_sdlc, test_data)


@pytest.mark.benchmark(group="crc_16_iso_iec_14443_3_a")
def test_crc_16_iso_iec_14443_3_a(benchmark):
    benchmark(crc16.iso_iec_14443_3_a, test_data)


@pytest.mark.benchmark(group="crc_16_kermit")
def test_crc_16_kermit(benchmark):
    benchmark(crc16.kermit, test_data)


@pytest.mark.benchmark(group="crc_16_lj1200")
def test_crc_16_lj1200(benchmark):
    benchmark(crc16.lj1200, test_data)


@pytest.mark.benchmark(group="crc_16_maxim_dow")
def test_crc_16_maxim_dow(benchmark):
    benchmark(crc16.maxim_dow, test_data)


@pytest.mark.benchmark(group="crc_16_mcrf4xx")
def test_crc_16_mcrf4xx(benchmark):
    benchmark(crc16.mcrf4xx, test_data)


@pytest.mark.benchmark(group="crc_16_modbus")
def test_crc_16_modbus(benchmark):
    benchmark(crc16.modbus, test_data)


@pytest.mark.benchmark(group="crc_16_nrsc_5")
def test_crc_16_nrsc_5(benchmark):
    benchmark(crc16.nrsc_5, test_data)


@pytest.mark.benchmark(group="crc_16_opensafety_a")
def test_crc_16_opensafety_a(benchmark):
    benchmark(crc16.opensafety_a, test_data)


@pytest.mark.benchmark(group="crc_16_opensafety_b")
def test_crc_16_opensafety_b(benchmark):
    benchmark(crc16.opensafety_b, test_data)


@pytest.mark.benchmark(group="crc_16_profibus")
def test_crc_16_profibus(benchmark):
    benchmark(crc16.profibus, test_data)


@pytest.mark.benchmark(group="crc_16_riello")
def test_crc_16_riello(benchmark):
    benchmark(crc16.riello, test_data)


@pytest.mark.benchmark(group="crc_16_spi_fujitsu")
def test_crc_16_spi_fujitsu(benchmark):
    benchmark(crc16.spi_fujitsu, test_data)


@pytest.mark.benchmark(group="crc_16_t10_dif")
def test_crc_16_t10_dif(benchmark):
    benchmark(crc16.t10_dif, test_data)


@pytest.mark.benchmark(group="crc_16_teledisk")
def test_crc_16_teledisk(benchmark):
    benchmark(crc16.teledisk, test_data)


@pytest.mark.benchmark(group="crc_16_tms37157")
def test_crc_16_tms37157(benchmark):
    benchmark(crc16.tms37157, test_data)


@pytest.mark.benchmark(group="crc_16_umts")
def test_crc_16_umts(benchmark):
    benchmark(crc16.umts, test_data)


@pytest.mark.benchmark(group="crc_16_usb")
def test_crc_16_usb(benchmark):
    benchmark(crc16.usb, test_data)


@pytest.mark.benchmark(group="crc_16_xmodem")
def test_crc_16_xmodem(benchmark):
    benchmark(crc16.xmodem, test_data)


@pytest.mark.benchmark(group="crc_32_aixm")
def test_crc_32_aixm(benchmark):
    benchmark(crc32.aixm, test_data)


@pytest.mark.benchmark(group="crc_32_autosar")
def test_crc_32_autosar(benchmark):
    benchmark(crc32.autosar, test_data)


@pytest.mark.benchmark(group="crc_32_base91_d")
def test_crc_32_base91_d(benchmark):
    benchmark(crc32.base91_d, test_data)


@pytest.mark.benchmark(group="crc_32_bzip2")
def test_crc_32_bzip2(benchmark):
    benchmark(crc32.bzip2, test_data)


@pytest.mark.benchmark(group="crc_32_cd_rom_edc")
def test_crc_32_cd_rom_edc(benchmark):
    benchmark(crc32.cd_rom_edc, test_data)


@pytest.mark.benchmark(group="crc_32_cksum")
def test_crc_32_cksum(benchmark):
    benchmark(crc32.cksum, test_data)


@pytest.mark.benchmark(group="crc_32_iscsi")
def test_crc_32_iscsi(benchmark):
    benchmark(crc32.iscsi, test_data)


@pytest.mark.benchmark(group="crc_32_iso_hdlc")
def test_crc_32_iso_hdlc(benchmark):
    benchmark(crc32.iso_hdlc, test_data)


@pytest.mark.benchmark(group="crc_32_jamcrc")
def test_crc_32_jamcrc(benchmark):
    benchmark(crc32.jamcrc, test_data)


@pytest.mark.benchmark(group="crc_32_mpeg_2")
def test_crc_32_mpeg_2(benchmark):
    benchmark(crc32.mpeg_2, test_data)


@pytest.mark.benchmark(group="crc_32_xfer")
def test_crc_32_xfer(benchmark):
    benchmark(crc32.xfer, test_data)


@pytest.mark.benchmark(group="crc_64_ecma_182")
def test_crc_64_ecma_182(benchmark):
    benchmark(crc64.ecma_182, test_data)


@pytest.mark.benchmark(group="crc_64_go_iso")
def test_crc_64_go_iso(benchmark):
    benchmark(crc64.go_iso, test_data)


@pytest.mark.benchmark(group="crc_64_we")
def test_crc_64_we(benchmark):
    benchmark(crc64.we, test_data)


@pytest.mark.benchmark(group="crc_64_xz")
def test_crc_64_xz(benchmark):
    benchmark(crc64.xz, test_data)
